@@ -5,7 +5,7 @@
 
 from plating.adorner.adorner import PlatingAdorner
 from plating.adorner.api import adorn_components, adorn_missing_components
-from plating.adorner.templates import TemplateGenerator
+from plating.templating.generator import TemplateGenerator
 
 __all__ = [
     "PlatingAdorner",
