@@ -2,11 +2,10 @@ from __future__ import annotations
 
 from plating.generation.adorner import DocumentationAdorner
 from plating.generation.plater import DocumentationPlater
-from plating.generation.renderer import TemplateRenderer
 
 #
 # plating/generation/__init__.py
 #
 """Documentation generation and rendering utilities."""
 
-__all__ = ["DocumentationAdorner", "DocumentationPlater", "TemplateRenderer"]
+__all__ = ["DocumentationAdorner", "DocumentationPlater"]
